pub enum Request {
Block {
transaction_hash: Hash,
transaction: Arc<Transaction>,
known_outpoint_hashes: Arc<HashSet<Hash>>,
known_utxos: Arc<HashMap<OutPoint, OrderedUtxo>>,
height: Height,
time: DateTime<Utc>,
},
Mempool {
transaction: UnminedTx,
height: Height,
},
}Expand description
Specifies whether a transaction should be verified as part of a block or as part of the mempool.
Transaction verification has slightly different consensus rules, depending on whether the transaction is to be included in a block on in the mempool.
Variants
Block
Verify the supplied transaction as part of a block.
Fields
transaction: Arc<Transaction>The transaction itself.
known_outpoint_hashes: Arc<HashSet<Hash>>Set of transaction hashes that create new transparent outputs.
known_utxos: Arc<HashMap<OutPoint, OrderedUtxo>>Additional UTXOs which are known at the time of verification.
Mempool
Verify the supplied transaction as part of the mempool.
Mempool transactions do not have any additional UTXOs.
Note: coinbase transactions are invalid in the mempool
Implementations
Sourceimpl Request
impl Request
Sourcepub fn transaction(&self) -> Arc<Transaction>
pub fn transaction(&self) -> Arc<Transaction>
The transaction to verify that’s in this request.
Sourcepub fn mempool_transaction(&self) -> Option<UnminedTx>
pub fn mempool_transaction(&self) -> Option<UnminedTx>
The unverified mempool transaction, if this is a mempool request.
Sourcepub fn tx_id(&self) -> UnminedTxId
pub fn tx_id(&self) -> UnminedTxId
The unmined transaction ID for the transaction in this request.
Sourcepub fn tx_mined_id(&self) -> Hash
pub fn tx_mined_id(&self) -> Hash
The mined transaction ID for the transaction in this request.
Sourcepub fn known_utxos(&self) -> Arc<HashMap<OutPoint, OrderedUtxo>>
pub fn known_utxos(&self) -> Arc<HashMap<OutPoint, OrderedUtxo>>
The set of additional known unspent transaction outputs that’s in this request.
Sourcepub fn known_outpoint_hashes(&self) -> Arc<HashSet<Hash>>
pub fn known_outpoint_hashes(&self) -> Arc<HashSet<Hash>>
The set of additional known transparent::OutPoints of unspent transaction outputs that’s in this request.
Sourcepub fn height(&self) -> Height
pub fn height(&self) -> Height
The height used to select the consensus rules for verifying this transaction.
Sourcepub fn block_time(&self) -> Option<DateTime<Utc>>
pub fn block_time(&self) -> Option<DateTime<Utc>>
The block time used for lock time consensus rules validation.
Sourcepub fn upgrade(&self, network: &Network) -> NetworkUpgrade
pub fn upgrade(&self, network: &Network) -> NetworkUpgrade
The network upgrade to consider for the verification.
This is based on the block height from the request, and the supplied network.
Sourcepub fn is_mempool(&self) -> bool
pub fn is_mempool(&self) -> bool
Returns true if the request is a mempool request.