pub enum Response {
Block {
tx_id: UnminedTxId,
miner_fee: Option<Amount<NonNegative>>,
sigops: u32,
},
Mempool {
transaction: VerifiedUnminedTx,
spent_mempool_outpoints: Vec<OutPoint>,
},
}Expand description
The response type for the transaction verifier service. Responses identify the transaction that was verified.
Variants
Block
A response to a block transaction verification request.
Fields
tx_id: UnminedTxIdThe witnessed transaction ID for this transaction.
Response::Block responses can be uniquely identified by
UnminedTxId::mined_id, because the block’s authorizing data root
will be checked during contextual validation.
miner_fee: Option<Amount<NonNegative>>The miner fee for this transaction.
None for coinbase transactions.
Consensus
The remaining value in the transparent transaction value pool of a coinbase transaction is destroyed.
Mempool
A response to a mempool transaction verification request.
Fields
transaction: VerifiedUnminedTxThe full content of the verified mempool transaction. Also contains the transaction fee and other associated fields.
Mempool transactions always have a transaction fee, because coinbase transactions are rejected from the mempool.
Response::Mempool responses are uniquely identified by the
UnminedTxId variant for their transaction version.
spent_mempool_outpoints: Vec<OutPoint>A list of spent transparent::OutPoints that were found in
the mempool’s list of created_outputs.
Used by the mempool to determine dependencies between transactions in the mempool and to avoid adding transactions with missing spends to its verified set.
Implementations
Sourceimpl Response
impl Response
Sourcepub fn tx_id(&self) -> UnminedTxId
pub fn tx_id(&self) -> UnminedTxId
The unmined transaction ID for the transaction in this response.
Sourcepub fn miner_fee(&self) -> Option<Amount<NonNegative>>
pub fn miner_fee(&self) -> Option<Amount<NonNegative>>
The miner fee for the transaction in this response.
Coinbase transactions do not have a miner fee, and they don’t need UTXOs to calculate their value balance, because they don’t spend any inputs.
Sourcepub fn sigops(&self) -> u32
pub fn sigops(&self) -> u32
The number of legacy transparent signature operations in this transaction’s inputs and outputs.
Sourcepub fn is_mempool(&self) -> bool
pub fn is_mempool(&self) -> bool
Returns true if the request is a mempool request.