fn dispatch_version_verification(
tx: &Transaction,
nu: NetworkUpgrade,
script_verifier: Verifier,
cached_ffi_transaction: Arc<CachedFfiTransaction>,
) -> Result<AsyncChecks, TransactionError>Expand description
Dispatches version-specific async verification checks for tx.
nu is the network upgrade active at the transaction’s verification height,
pre-computed by the caller using NetworkUpgrade::current.
Returns TransactionError::WrongVersion for V1-V3 transactions, which
are not supported by any network upgrade Zebra verifies.