verify_v4_transaction

Function verify_v4_transaction 

fn verify_v4_transaction(
    tx: &Transaction,
    nu: NetworkUpgrade,
    script_verifier: Verifier,
    cached_ffi_transaction: Arc<CachedFfiTransaction>,
) -> Result<AsyncChecks, TransactionError>
Verify a V4 transaction.

Returns a set of asynchronous checks that must all succeed for the transaction to be considered valid. These checks include:

  • transparent transfers
  • sprout shielded data
  • sapling shielded data

The parameters of this method are:

  • the tx transaction to verify
  • the nu network upgrade active at the transaction’s verification height
  • the script_verifier to use for verifying the transparent transfers
  • the prepared cached_ffi_transaction used by the script verifier