fn verify_v5_transaction(
tx: &Transaction,
nu: NetworkUpgrade,
script_verifier: Verifier,
cached_ffi_transaction: Arc<CachedFfiTransaction>,
) -> Result<AsyncChecks, TransactionError>Expand description
Verify a V5 transaction.
Returns a set of asynchronous checks that must all succeed for the transaction to be considered valid. These checks include:
- transaction support by the selected network upgrade, as checked by
verify_v5_transaction_network_upgrade - transparent transfers
- sapling shielded data (TODO)
- orchard shielded data (TODO)
The parameters of this method are:
- the
txtransaction to verify - the
nunetwork upgrade active at the transaction’s verification height - the
script_verifierto use for verifying the transparent transfers - the prepared
cached_ffi_transactionused by the script verifier