pub struct MempoolTxVerifier<ZS, Mempool> {
network: Network,
state: Timeout<ZS>,
mempool: Option<Timeout<Mempool>>,
script_verifier: Verifier,
mempool_setup_rx: Receiver<Mempool>,
}Expand description
Fields
network: Networkstate: Timeout<ZS>mempool: Option<Timeout<Mempool>>script_verifier: Verifiermempool_setup_rx: Receiver<Mempool>Implementations
Sourceimpl<ZS, Mempool> MempoolTxVerifier<ZS, Mempool>
impl<ZS, Mempool> MempoolTxVerifier<ZS, Mempool>
Sourceimpl<ZS, Mempool> MempoolTxVerifier<ZS, Mempool>
impl<ZS, Mempool> MempoolTxVerifier<ZS, Mempool>
Sourceasync fn verify_mempool_lock_time(
tx: &Transaction,
height: Height,
state: Timeout<ZS>,
) -> Result<(), TransactionError>
async fn verify_mempool_lock_time( tx: &Transaction, height: Height, state: Timeout<ZS>, ) -> Result<(), TransactionError>
Validates mempool lock-time consensus rules.
Queries state only for time-based lock times.
Sourceasync fn mempool_best_chain_next_median_time_past(
state: Timeout<ZS>,
) -> Result<DateTime32, TransactionError>
async fn mempool_best_chain_next_median_time_past( state: Timeout<ZS>, ) -> Result<DateTime32, TransactionError>
Fetches the median-time-past of the next block after the best state tip.
This is used to verify that the lock times of mempool transactions can be included in any valid next block.
Sourceasync fn mempool_spent_utxos(
tx: Arc<Transaction>,
height: Height,
state: Timeout<ZS>,
mempool: Option<Timeout<Mempool>>,
) -> Result<(HashMap<OutPoint, Utxo>, Vec<Output>, Vec<OutPoint>), TransactionError>
async fn mempool_spent_utxos( tx: Arc<Transaction>, height: Height, state: Timeout<ZS>, mempool: Option<Timeout<Mempool>>, ) -> Result<(HashMap<OutPoint, Utxo>, Vec<Output>, Vec<OutPoint>), TransactionError>
Looks up UTXOs spent by a mempool tx, first querying the best chain state
and then the mempool for inputs whose outputs are not present in the best chain.
height is the next block height, used to construct Utxo values for
outputs sourced from the mempool.
Returns an OutPoint -> Utxo map, a vec of Outputs in the same order
as the matching inputs in tx, and a vec of OutPoints that were
sourced from the mempool rather than the best chain.