fn verify_v4_transaction(
tx: &Transaction,
nu: NetworkUpgrade,
script_verifier: Verifier,
cached_ffi_transaction: Arc<CachedFfiTransaction>,
) -> Result<AsyncChecks, TransactionError>Expand description
Verify a V4 transaction.
Returns a set of asynchronous checks that must all succeed for the transaction to be considered valid. These checks include:
- transparent transfers
- sprout shielded data
- sapling shielded data
The parameters of this method are:
- the
txtransaction to verify - the
nunetwork upgrade active at the transaction’s verification height - the
script_verifierto use for verifying the transparent transfers - the prepared
cached_ffi_transactionused by the script verifier